==> media_contextual_crop-2.0.0.tar.gz: media_contextual_crop/src/PathProcessor/PathProcessorImageStyles.php <==
<?php

namespace Drupal\media_contextual_crop\PathProcessor;

use Drupal\image\PathProcessor\PathProcessorImageStyles as BaseFromImage;
use Symfony\Component\HttpFoundation\Request;

/**
 * Defines a path processor to rewrite contextualized image styles URLs.
 *
 * @see \Drupal\image\PathProcessor\PathProcessorImageStyles;
 */
class PathProcessorImageStyles extends BaseFromImage {

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request) {

    $directory_path = $this->streamWrapperManager->getViaScheme('public')->getDirectoryPath();
    if (strpos($path, '/' . $directory_path . '/context/') === 0) {
      $path_prefix = '/' . $directory_path . '/context/';
    }
    // Check if the string '/system/files/styles/' exists inside the path,
    // that means we have a case of private file's image style.
    elseif (str_contains($path, '/system/files/context/')) {
      $path_prefix = '/system/files/context/';
      $path = substr($path, strpos($path, $path_prefix), strlen($path));
    }
    else {
      return $path;
    }

    // Strip out path prefix.
    $rest = preg_replace('|^' . preg_quote($path_prefix, '|') . '|', '', $path);

    // Get the image style, scheme and path.
    if (substr_count($rest, '/') >= 4) {
      [$context, $style_separator, $image_style, $scheme, $file] = explode('/', $rest, 5);

      // Set the file & context as query parameter.
      $request->query->set('file', $file);
      $request->query->set('contextual_crop', $context);

      return $path_prefix . $context . '/' . $style_separator . '/' . $image_style . '/' . $scheme;
    }
    else {
      return $path;
    }
  }

}

==> media_contextual_crop-2.0.2.tar.gz: media_contextual_crop/src/PathProcessor/PathProcessorImageStyles.php <==
<?php

namespace Drupal\media_contextual_crop\PathProcessor;

use Drupal\image\PathProcessor\PathProcessorImageStyles as BaseFromImage;
use Symfony\Component\HttpFoundation\Request;

/**
 * Defines a path processor to rewrite contextualized image styles URLs.
 *
 * @see \Drupal\image\PathProcessor\PathProcessorImageStyles;
 */
class PathProcessorImageStyles extends BaseFromImage {

  /**
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request) {

    $directory_path = $this->streamWrapperManager->getViaScheme('public')->getDirectoryPath();
    if (strpos($path, '/' . $directory_path . '/contextual/') === 0) {
      $path_prefix = '/' . $directory_path . '/contextual/';
    }
    // Check if the string '/system/files/styles/' exists inside the path,
    // that means we have a case of private file's image style.
    elseif (str_contains($path, '/system/files/contextual/')) {
      $path_prefix = '/system/files/contextual/';
      $path = substr($path, strpos($path, $path_prefix), strlen($path));
    }
    else {
      return $path;
    }

    // Strip out path prefix.
    $rest = preg_replace('|^' . preg_quote($path_prefix, '|') . '|', '', $path);

    // Get the image style, scheme and path.
    if (substr_count($rest, '/') >= 4) {
      [$style_separator, $image_style, $context, $scheme, $file] = explode('/', $rest, 5);

      // Set the file & context as query parameter.
      $request->query->set('file', $file);
      $request->query->set('contextual_crop', $context);

      return $path_prefix . $style_separator . '/' . $image_style . '/' . $context . '/' . $scheme;
    }
    else {
      return $path;
    }
  }

}
